==> prt-engine-java-1.0.1-2.4T02-sources.jar: com/stream/prt/PrtEvent.java <==
package com.stream.prt;

public class PrtEvent {
    public static final int event_proxy_no_signa = 0x1001;
    public static final int event_proxy_verify = 0x1002;
    public static final int event_change_stream_no_signal = 0x1003;
    public static final int event_change_stream_restart_player = 0x1004;
    public static final int event_switch_chan_continue = 0x1005;
    public static final int event_change_prt_server_id = 0x1006;

    private int channelId;
    private int event;
    private String param;
    private String desc;

    public PrtEvent(int channelId, int event, String param, String desc) {
        this.channelId = channelId;
        this.event = event;
        this.param = param;
        this.desc = desc;
    }

    public int getChannelId() {
        return channelId;
    }

    public void setChannelId(int channelId) {
        this.channelId = channelId;
    }

    public int getEvent() {
        return event;
    }

    public void setEvent(int event) {
        this.event = event;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    @Override
    public String toString() {
        return "PrtEvent{" +
                "channelId=" + channelId +
                ", event=" + event +
                ", param='" + param + '\'' +
                ", desc='" + desc + '\'' +
                '}';
    }
}

==> prt-engine-java-1.1.3-4.2T02-sources.jar: com/stream/prt/PrtEvent.java <==
package com.stream.prt;

public class PrtEvent {
    public static final int event_proxy_no_signa = 0x1001;
    public static final int event_proxy_verify = 0x1002;
    public static final int event_change_stream_no_signal = 0x1003;
    public static final int event_change_stream_restart_player = 0x1004;
    public static final int event_switch_chan_continue = 0x1005;
    public static final int event_change_prt_server_id = 0x1006;
    public static final int event_front_start_player = 0x2004;
    public static final int event_front_info_to_play = 0x2005;
    public static final int event_abr_info = 0x2008;
    public static final int event_connect_token_expired = 0x2101;

    private int channelId;
    private int event;
    private String param;
    private String desc;

    public PrtEvent(int channelId, int event, String param, String desc) {
        this.channelId = channelId;
        this.event = event;
        this.param = param;
        this.desc = desc;
    }

    public int getChannelId() {
        return channelId;
    }

    public void setChannelId(int channelId) {
        this.channelId = channelId;
    }

    public int getEvent() {
        return event;
    }

    public void setEvent(int event) {
        this.event = event;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    @Override
    public String toString() {
        return "PrtEvent{" +
                "channelId=" + channelId +
                ", event=" + event +
                ", param='" + param + '\'' +
                ", desc='" + desc + '\'' +
                '}';
    }
}
